@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Bookmarks" : "Markah",
     "No file provided for import" : "Berkas untuk impor tidak tersedia",
-    "Unsupported file type for import" : "Tipe berkas untuk impor tidak didukung",
     "Bookmarks shared by %s" : "Markah dibagikan oleh %s",
     "Select bookmark" : "Pilih markah",
     "Details" : "Detil",
@@ -15,8 +14,6 @@ OC.L10N.register(
     "Delete selection" : "Hapus pilihan",
     "Select all" : "Pilih semua",
     "Cancel selection" : "Batalkan pilihan",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Memilih %n markah"],
-    "_Selected %n folder_::_Selected %n folders_" : ["Memilih %n folder"],
     "Go back" : "Kembali",
     "Select one or more tags" : "Pilih satu atau lebih tag",
     "New" : "Baru",
@@ -30,15 +27,11 @@ OC.L10N.register(
     "Shared by {user}" : "Dibagikan oleh {user}",
     "Rename folder" : "Ubah nama folder",
     "Cancel" : "Membatalkan",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Memindahkan %n folder dan beberapa markah"],
-    "_Moving %n folder_::_Moving %n folders_" : ["Memindahkan %n folder"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Memindahkan %n markah"],
     "Recent" : "Terbaru",
     "Shared with you" : "Shared with you",
     "Files" : "Berkas",
     "Delete" : "Hapus",
     "Untagged" : "Belum ada tag",
-    "Settings" : "Setelan",
     "No bookmarks here" : "Tidak ada markah di sini",
     "Client apps" : "Aplikasi klien",
     "Need help?" : "Butuh bantuan?",
