@@ -26,7 +26,7 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "%1$s s vami zrušil zdieľanie priečinka „%2$s“",
     "Someone unshared folder \"%s\" with you" : "Niekto s vami zrušil zdieľanie priečinka „%s“",
     "No file provided for import" : "Nie je k dispozícii žiadny súbor na import",
-    "Unsupported file type for import" : "Nepodporovaný typ súboru na import",
+    "Failed to upload file" : "Chyba pri nahrávaní súboru",
     "Bookmarks shared by %s" : "Záložky, ktoré zdieľa %s",
     "Frequent bookmarks" : "Časté záložky",
     "Recent bookmarks" : "Aktuálne záložky",
@@ -40,11 +40,16 @@ OC.L10N.register(
     "Bookmarks Backups" : "Zálohy záložiek",
     "Enter new title" : "Zadajte nový nadpis",
     "Select bookmark" : "Vybrať záložku",
+    "You have never clicked this link" : "Na tento odkaz ste nikdy neklikli",
+    "You have clicked this link {count} times" : "Na tento link ste klikli {count} krát",
     "Details" : "Detaily",
     "Rename" : "Premenovať",
     "Copy link" : "Kopíruj odkaz",
     "Move" : "Presunúť",
     "Add to folders" : "Pridať do priečinkov",
+    "Put bookmark into trash bin" : "Zahodiť záložku do koša",
+    "Restore bookmark" : "Obnoviť záložku",
+    "Delete bookmark permanently" : "Natrvalo odstrániť záložku",
     "Do you really want to delete this bookmark?" : "Naozaj chcete zmazať všetky svoje záložky?",
     "Link copied to clipboard" : "Odkaz bol skopírovaný do schránky",
     "Content pending" : "Čakajúci obsah",
@@ -65,10 +70,10 @@ OC.L10N.register(
     "Cancel selection" : "Zrušiť výber",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Vybraté {folders} priečinky a {bookmarks} záložky",
     "Do you really want to delete these items?" : "Naozaj chcete odstrániť tieto položky?",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Vybraná %n záložka","Vybrané %n záložky","Vybrané %n záložky","Vybraných %n záložiek"],
-    "_Selected %n folder_::_Selected %n folders_" : ["Vybratý %n priečinok","Vybraté %n priečinky","Vybraté %n priečinky","Vybratých %n priečinkov"],
+    "Trash Bin" : "Kôš",
     "Go back" : "Ísť späť",
     "Share folder" : "Sprístupniť priečinok",
+    "Open folder details" : "Otvoriť podrobnosti o adresáre",
     "Select one or more tags" : "Zvoliť jeden alebo viac štítkov",
     "New" : "Nový",
     "New bookmark" : "Nová záložka",
@@ -86,13 +91,10 @@ OC.L10N.register(
     "Sort by manual order" : "Zoradiť manuálne",
     "Sort by URL" : "Zoradiť podľa URL",
     "RSS feed copied" : "RSS kanál je skopírovaný",
-    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Pridávam %n záložku do nového priečinka","Pridávam %n záložiek do nového priečinka","Pridávam %n záložiek do nového priečinka","Pridávam %n záložiek do nového priečinka"],
     "Enter a link" : "Zadať link",
     "Enter a title" : "Zadať názov",
     "No bookmarks found" : "Žiadne záložky neboli nájdené",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} priečinky a {bookmarks} záložky",
-    "_%n bookmark_::_%n bookmarks_" : ["%n záložka","%n záložiek","%n záložiek","%n záložiek"],
-    "_%n folder_::_%n folders_" : ["%n priečinok","%n priečinkov","%n priečinkov","%n priečinkov"],
     "Welcome to Bookmarks" : "Vitajte v Záložkách",
     "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Táto aplikácia vám umožňuje spravovať odkazy na vaše obľúbené miesta na webe. Roztrieďte svoje záložky do priečinkov, označte ich štítkami a sprístupnite ich ostatným! Aplikácia pravidelne kontroluje dostupnosť všetkých vašich odkazov a zobrazuje nedostupné odkazy. Ak pridáte odkaz na súbor na webe, súbor sa automaticky stiahne do vašich Nextcloud Súborov. Môžete tiež importovať záložky exportované z iných služieb alebo priamo synchronizovať záložky zo všetkých svojich prehliadačov pomocou tejto aplikácie.",
     "Add a bookmark" : "Pridať záložku",
@@ -103,6 +105,10 @@ OC.L10N.register(
     "Shared by {user}" : "Zdieľa {user}",
     "Rename folder" : "Premenovať priečinok",
     "Move folder" : "Presunúť priečinok",
+    "Put folder into trashbin" : "Zahodiť adresár do koša",
+    "Restore folder" : "Obnoviť adresár",
+    "Delete folder permanently" : "Narvalo odstrániť adresár",
+    "Do you really want to permanently delete this folder?" : "Naozaj chcete navždy zmazať tento adresár?",
     "Choose folder" : "Vyberte priečinok",
     "Submit" : "Odoslať",
     "Cancel" : "Zrušiť",
@@ -111,9 +117,7 @@ OC.L10N.register(
     "Importing bookmarks" : "Importujem záložky",
     "Moving selection" : "Presúvam vybrané",
     "Adding selection to folders" : "Pridávam vybrané do priečinkov",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Presúva sa %n priečinok a niektoré záložky","Presúvajú sa %n priečinky a niektoré záložky","Presúvajú sa %n priečinky a niektoré záložky","Presúva sa %n priečinkov a niektoré záložky"],
-    "_Moving %n folder_::_Moving %n folders_" : ["Presúva sa %n priečinok","Presúvajú sa %n priečinky","Presúvajú sa %n priečinky","Presúva sa %n priečinkov"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Presúva sa %n záložka","Presúvajú sa %n záložky","Presúvajú sa %n záložky","Presúva sa %n záložiek"],
+    "Emptying trashbin" : "Vyprázdňujem kôš",
     "All bookmarks" : "Všetky záložky",
     "Recent" : "Nedávne",
     "Shared with you" : "Zdieľané s vami",
@@ -125,7 +129,7 @@ OC.L10N.register(
     "Delete" : "Zmazať",
     "Untagged" : "Bez štítku",
     "{used} bookmarks of {available} available" : "{used} záložky z {available} dostupných",
-    "Settings" : "Nastavenia",
+    "Bookmarks Settings" : "Nastavenia Záložiek",
     "No bookmarked files" : "Žiadne záložky súborov",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Záložky súborov, ako sú fotografie alebo PDF, sa automaticky uložia do vašich súborov Nextcloud, takže ich stále nájdete, aj keď je odkaz offline.",
     "Nothing found" : "Nič sa nenašlo",
@@ -133,6 +137,7 @@ OC.L10N.register(
     "No broken links" : "Žiadne poškodené odkazy",
     "No shared folders" : "Žiadne zdieľané priečinky",
     "No duplicated bookmarks" : "Žiadne duplikovanéq záložky",
+    "No deleted bookmarks" : "Žiadne zmazané záložky",
     "You haven't deleted anything yet." : "Zatiaľ ste nič neodstránili.",
     "No bookmarks here" : "Žiadne záložky",
     "Add bookmarks manually or import bookmarks from a HTML file." : "Pridajte záložky ručne alebo ich importujte z HTML súboru.",
@@ -143,6 +148,7 @@ OC.L10N.register(
     "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Aplikácia na záložky môže automaticky archivovať webový obsah odkazov, ktoré ste si uložili do záložiek.",
     "Enable archiving" : "Povoliť archivovanie",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "Vložte cestu k priečinku kde sa budú ukladať súbory v záložkách.",
+    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Váš správca však momentálne zakázal tejto aplikácii prístup k sieti, a preto je automatická archivácia momentálne zakázaná.",
     "Auto-Backup" : "Auto-zálohovanie",
     "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Aplikácia na záložky môže automaticky zálohovať vaše záložky denne, aby sa zabránilo strate údajov pri synchronizácii záložiek medzi zariadeniami.",
     "Enable backups" : "Povoliť zálohovanie",
@@ -156,6 +162,9 @@ OC.L10N.register(
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Potiahnite túto položku do záložiek prehliadača a kliknutím pridajte stránku do záložiek.",
     "Add to {instanceName}" : "Pridať do {instanceName}",
     "Need help?" : "Potrebujete pomoc?",
+    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Ak máte problémy s aplikáciou Záložky alebo máte nápad, čo by sa dalo zlepšiť, neváhajte nás kontaktovať kliknutím sem.",
+    "Support this project" : "Podporte tente projekt",
+    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Moja práca na aplikácii Záložky je poháňaná modelom dobrovoľného predplatného. Ak si myslíte, že to, čo robím, má zmysel, budem rád, ak podporíte moju prácu. Zvážte tiež, že by ste aplikácii dali recenziu v obchode s aplikáciami Nextcloud. Ďakujem 💙",
     "Archive path" : "Archivovať cestu",
     "Backup path" : "Cesta k zálohám",
     "Please select \"Add to home screen\" in your browser menu" : "Prosím vyberte \"Pridať na domovskú obrazovku\" v menu vašeho prehliadača",
@@ -173,7 +182,7 @@ OC.L10N.register(
     "Created {time} ago" : "Vytvorené  {time} spätne",
     "Created on {date}" : "Vytvorené {date}",
     "Owner" : "Majiteľ",
-    "Sharing" : "Sprístupnenie",
+    "Sharing" : "Zdieľanie",
     "Select a user or group" : "Vyberte používateľa alebo skupinu",
     "Share link" : "Sprístupniť odkaz",
     "Reading allowed" : "Čítanie povolené",
@@ -183,9 +192,9 @@ OC.L10N.register(
     "Resharing allowed" : "Opätovné zdieľanie je povolené",
     "Editing allowed" : "Úpravy povolené",
     "Allow editing" : "Povoliť úpravy",
-    "Allow resharing" : "Povoliť sprístupňovanie ďalej",
+    "Allow resharing" : "Povoliť zdieľanie ďalej",
     "Remove share" : "Odstrániť zdieľanie",
-    "Link copied" : "Odkaz skopírovaný",
+    "Link copied" : "Odkaz bol skopírovaný",
     "Privacy" : "Súkromie",
     "Enable accessing and collecting information from the web pages you add" : "Povoľte prístup a zhromažďovanie informácií z pridaných webových stránok",
     "Performance" : "Výkon",
