@@ -1,4 +1,5 @@
 <?php
+
 /*
  * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
  *
@@ -26,7 +27,7 @@ class FileCacheGCJob extends TimedJob {
 	private $logger;
 
 	public function __construct(
-		FileCache $fileCache, LoggerInterface $logger, ITimeFactory $timeFactory
+		FileCache $fileCache, LoggerInterface $logger, ITimeFactory $timeFactory,
 	) {
 		parent::__construct($timeFactory);
 		$this->setInterval(self::INTERVAL);
@@ -38,7 +39,7 @@ class FileCacheGCJob extends TimedJob {
 		try {
 			$this->fileCache->gc();
 		} catch (NotPermittedException $e) {
-			$this->logger->error('Could not collect garbage: '.$e->getMessage());
+			$this->logger->error('Could not collect garbage: ' . $e->getMessage());
 		}
 	}
 }
