@@ -1,4 +1,5 @@
 <?php
+
 /*
  * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
  *
@@ -57,6 +58,7 @@ class TreeMapper extends QBMapper {
 	private IQueryBuilder $insertQuery;
 
 	private IQueryBuilder $parentQuery;
+	private IQueryBuilder $parentQueryWithoutSoftDeletions;
 
 	private array $getChildrenQuery;
 	private array $getSoftDeletedChildrenQuery;
@@ -100,6 +102,7 @@ class TreeMapper extends QBMapper {
 
 		$this->insertQuery = $this->getInsertQuery();
 		$this->parentQuery = $this->getParentQuery();
+		$this->parentQueryWithoutSoftDeletions = $this->getParentQueryWithoutSoftDeletions();
 		$this->getChildrenOrderQuery = $this->getGetChildrenOrderQuery();
 		$this->getChildrenQuery = [
 			TreeMapper::TYPE_BOOKMARK => $this->getFindChildrenQuery(TreeMapper::TYPE_BOOKMARK),
@@ -198,6 +201,16 @@ class TreeMapper extends QBMapper {
 		return $qb;
 	}
 
+	protected function getParentQueryWithoutSoftDeletions(): IQueryBuilder {
+		$qb = $this->selectFromType(TreeMapper::TYPE_FOLDER);
+		$qb
+			->join('i', 'bookmarks_tree', 't', $qb->expr()->eq('t.parent_folder', 'i.id'))
+			->where($qb->expr()->eq('t.id', $qb->createParameter('id')))
+			->andWhere($qb->expr()->eq('t.type', $qb->createParameter('type')))
+			->andWhere($qb->expr()->isNull('t.soft_deleted_at'));
+		return $qb;
+	}
+
 	protected function getParentQuery(): IQueryBuilder {
 		$qb = $this->selectFromType(TreeMapper::TYPE_FOLDER);
 		$qb
@@ -221,11 +234,11 @@ class TreeMapper extends QBMapper {
 	protected function getFindChildrenQuery(string $type): IQueryBuilder {
 		$qb = $this->selectFromType($type);
 		$qb
-				->join('i', 'bookmarks_tree', 't', $qb->expr()->eq('t.id', 'i.id'))
-				->where($qb->expr()->eq('t.parent_folder', $qb->createParameter('parent_folder')))
-				->andWhere($qb->expr()->eq('t.type', $qb->createNamedParameter($type)))
-				->andWhere($qb->expr()->isNull('t.soft_deleted_at'))
-				->orderBy('t.index', 'ASC');
+			->join('i', 'bookmarks_tree', 't', $qb->expr()->eq('t.id', 'i.id'))
+			->where($qb->expr()->eq('t.parent_folder', $qb->createParameter('parent_folder')))
+			->andWhere($qb->expr()->eq('t.type', $qb->createNamedParameter($type)))
+			->andWhere($qb->expr()->isNull('t.soft_deleted_at'))
+			->orderBy('t.index', 'ASC');
 		return $qb;
 	}
 
@@ -283,8 +296,12 @@ class TreeMapper extends QBMapper {
 	 * @return Entity[]
 	 * @psalm-return list<Folder>
 	 */
-	public function findParentsOf(string $type, int $itemId): array {
-		$qb = $this->parentQuery;
+	public function findParentsOf(string $type, int $itemId, $withSoftDeletions = false): array {
+		if ($withSoftDeletions === true) {
+			$qb = $this->parentQuery;
+		} else {
+			$qb = $this->parentQueryWithoutSoftDeletions;
+		}
 		$qb->setParameters([
 			'id' => $itemId,
 			'type' => $type,
@@ -320,12 +337,12 @@ class TreeMapper extends QBMapper {
 	 * @return bool
 	 */
 	public function hasDescendant(int $folderId, string $type, int $descendantId): bool {
-		$ancestors = $this->findParentsOf($type, $descendantId);
+		$ancestors = $this->findParentsOf($type, $descendantId, true);
 		while (!in_array($folderId, array_map(static function (Entity $ancestor) {
 			return $ancestor->getId();
 		}, $ancestors), true)) {
 			$ancestors = array_flatten(array_map(function (Entity $ancestor) {
-				return $this->findParentsOf(TreeMapper::TYPE_FOLDER, $ancestor->getId());
+				return $this->findParentsOf(TreeMapper::TYPE_FOLDER, $ancestor->getId(), true);
 			}, $ancestors));
 			if (count($ancestors) === 0) {
 				return false;
@@ -381,7 +398,7 @@ class TreeMapper extends QBMapper {
 			$qb = $this->db->getQueryBuilder();
 			$qb->select('b.id')
 				->from('bookmarks', 'b')
-				->leftJoin('b', 'bookmarks_tree', 't', 'b.id = t.id AND t.type = '.$qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
+				->leftJoin('b', 'bookmarks_tree', 't', 'b.id = t.id AND t.type = ' . $qb->createPositionalParameter(TreeMapper::TYPE_BOOKMARK))
 				->where($qb->expr()->isNull('t.id'));
 			$orphanedBookmarks = $qb->execute();
 			while ($bookmark = $orphanedBookmarks->fetchColumn()) {
@@ -402,7 +419,12 @@ class TreeMapper extends QBMapper {
 		}
 
 		if ($type === TreeMapper::TYPE_BOOKMARK) {
-			$this->removeFromFolders(TreeMapper::TYPE_BOOKMARK, $id, [$folderId]);
+			if ($folderId === null) {
+				$folders = array_map(fn (Folder $folder) => $folder->getId(), $this->findParentsOf(TreeMapper::TYPE_BOOKMARK, $id, true));
+			} else {
+				$folders = [$folderId];
+			}
+			$this->removeFromFolders(TreeMapper::TYPE_BOOKMARK, $id, $folders);
 		}
 	}
 
@@ -526,20 +548,21 @@ class TreeMapper extends QBMapper {
 			return;
 		}
 
-		// set entry as not deleted
-		// has to come last to not break findByAncestorFolder
-		$qb = $this->db->getQueryBuilder();
-		$qb
-			->update('bookmarks_tree')
-			->set('soft_deleted_at', $qb->createNamedParameter(null, IQueryBuilder::PARAM_DATE))
-			->where($qb->expr()->eq('id', $qb->createNamedParameter($id, IQueryBuilder::PARAM_INT)))
-			->andWhere($qb->expr()->eq('type', $qb->createNamedParameter($type, IQueryBuilder::PARAM_STR)));
-		if ($folderId !== null) {
-			$qb->set('index', $qb->createNamedParameter($this->countChildren($folderId)));
-			$qb->andWhere($qb->expr()->eq('parent_folder', $qb->createNamedParameter($folderId, IQueryBuilder::PARAM_INT)));
+		if ($this->isEntrySoftDeleted($type, $id, $folderId)) {
+			// set entry as not deleted
+			// has to come last to not break findByAncestorFolder
+			$qb = $this->db->getQueryBuilder();
+			$qb
+				->update('bookmarks_tree')
+				->set('soft_deleted_at', $qb->createNamedParameter(null, IQueryBuilder::PARAM_DATE))
+				->where($qb->expr()->eq('id', $qb->createNamedParameter($id, IQueryBuilder::PARAM_INT)))
+				->andWhere($qb->expr()->eq('type', $qb->createNamedParameter($type, IQueryBuilder::PARAM_STR)));
+			if ($folderId !== null) {
+				$qb->set('index', $qb->createNamedParameter($this->countChildren($folderId)));
+				$qb->andWhere($qb->expr()->eq('parent_folder', $qb->createNamedParameter($folderId, IQueryBuilder::PARAM_INT)));
+			}
+			$qb->executeStatement();
 		}
-		$qb->executeStatement();
-
 	}
 
 	/**
@@ -688,7 +711,7 @@ class TreeMapper extends QBMapper {
 		}
 		$currentFolders = array_map(static function (Folder $f) {
 			return $f->getId();
-		}, $this->findParentsOf($type, $itemId));
+		}, $this->findParentsOf($type, $itemId, true));
 
 		$folders = array_filter($folders, static function ($folderId) use ($currentFolders) {
 			return !in_array($folderId, $currentFolders, true);
@@ -722,7 +745,7 @@ class TreeMapper extends QBMapper {
 		if ($type !== TreeMapper::TYPE_BOOKMARK) {
 			throw new UnsupportedOperation('Only bookmarks can be in multiple folders');
 		}
-		$foldersLeft = count($this->findParentsOf($type, $itemId));
+		$foldersLeft = count($this->findParentsOf($type, $itemId, true));
 
 		foreach ($folders as $folderId) {
 			$qb = $this->db->getQueryBuilder();
@@ -754,7 +777,7 @@ class TreeMapper extends QBMapper {
 		$existingChildren = $this->getChildrenOrder($folderId);
 		foreach ($existingChildren as $child) {
 			if (!in_array($child, $newChildrenOrder, false)) {
-				throw new ChildrenOrderValidationError('A child is missing: '.$child['type'].':'.$child['id']);
+				throw new ChildrenOrderValidationError('A child is missing: ' . $child['type'] . ':' . $child['id']);
 			}
 			if (!isset($child['id'], $child['type'])) {
 				throw new ChildrenOrderValidationError('A child item is missing properties');
@@ -1125,7 +1148,7 @@ class TreeMapper extends QBMapper {
 	 * @param int $folderId
 	 * @param Share $share
 	 * @return boolean
-	 *@throws MultipleObjectsReturnedException
+	 * @throws MultipleObjectsReturnedException
 	 */
 	public function isFolderSharedWithUser(int $folderId, string $userId): bool {
 		try {
@@ -1135,14 +1158,18 @@ class TreeMapper extends QBMapper {
 			// noop
 		}
 
-		$ancestors = $this->findParentsOf(TreeMapper::TYPE_FOLDER, $folderId);
-		foreach ($ancestors as $ancestorFolder) {
-			try {
-				$this->sharedFolderMapper->findByFolderAndUser($ancestorFolder->getId(), $userId);
-				return true;
-			} catch (DoesNotExistException) {
-				// noop
+		try {
+			while ($ancestorFolder = $this->findParentOf(TreeMapper::TYPE_FOLDER, $folderId)) {
+				try {
+					$this->sharedFolderMapper->findByFolderAndUser($ancestorFolder->getId(), $userId);
+					return true;
+				} catch (DoesNotExistException) {
+					// noop
+				}
+				$folderId = $ancestorFolder->getId();
 			}
+		} catch (DoesNotExistException $e) {
+			// noop
 		}
 
 		return false;
@@ -1204,7 +1231,7 @@ class TreeMapper extends QBMapper {
 			$this->logger->error('Could not query for old trash bin items', ['exception' => $e]);
 			return;
 		}
-		while($row = $result->fetch()) {
+		while ($row = $result->fetch()) {
 			try {
 				$this->deleteEntry($row['type'], $row['id'], $row['parent_folder']);
 			} catch (DoesNotExistException $e) {
